@@ -13,6 +13,8 @@ from kensu.utils.dsl.lineage_builder import LineageBuilder
 from kensu.utils.helpers import to_hash_key
 from kensu.utils.injection import Injection
 from kensu.pandas import DataFrame,Series
+from kensu.utils.reporters import *
+
 
 
 class Kensu(object):
@@ -60,19 +62,34 @@ class Kensu(object):
                 code_version = code_version + " (dirty)"
         return code_version
 
+    @staticmethod
     def get_conf_path(self, default = "conf.ini"):
         return os.environ["CONF_FILE"] if "CONF_FILE" in os.environ else default
 
-    def __init__(self, api_url=None, auth_token=None, process_name=None,
-                 user_name=None, code_location=None, init_context=True, 
-                 do_report=None, report_to_file=None, offline_file_name=None, reporter=None, compute_stats=True, **kwargs):
+    @staticmethod
+    def build_conf():
         """
+        Returns configparser.ConfigParser
         """
         from configparser import ConfigParser, ExtendedInterpolation
-
         config = ConfigParser(interpolation=ExtendedInterpolation())
-        # TODO... path to conf there are so many args in the function here, so adding it will require a good migration plan (it doesn't land in kwargs...)
-        config.read(self.get_conf_path("conf.ini"))
+        conf_path = Kensu.get_conf_path("conf.ini")
+        try:
+            config.read(conf_path)
+        except:
+            logging.warn(f"Cannot load config from file `%s`" % (conf_path))
+        return config
+
+    def __init__(self, api_url=None, auth_token=None, process_name=None,
+                 user_name=None, code_location=None, init_context=True, 
+                 do_report=None, report_to_file=None, offline_file_name=None, 
+                 reporter=None, compute_stats=True, 
+                 config=None, **kwargs):
+        """
+        config: : configparser.ConfigParser if None `build_conf` will be tried
+        """
+        if config is None:
+            config = Kensu.build_conf()
 
         kensu_conf = config['kensu'] if config.has_section('kensu') else config['DEFAULT']
         self.conf = kensu_conf
@@ -114,6 +131,7 @@ class Kensu(object):
         logical_naming = kwargs_or_conf_or_default("logical_naming", None)
         mapping = kwargs_or_conf_or_default("mapping", None)
         report_in_mem = kwargs_or_conf_or_default("report_in_mem", False)
+        sql_util_url = kwargs_or_conf_or_default("sql_util_url", None)
 
         if "get_code_version" in kwargs and kwargs["get_code_version"] is not None:
             get_code_version = kwargs["get_code_version"]
@@ -129,6 +147,7 @@ class Kensu(object):
         user_name = default_if_arg_none(user_name, kensu_conf.get("user_name"))
         code_location = default_if_arg_none(code_location, kensu_conf.get("code_location"))
 
+        reporter = default_if_arg_none(reporter, kensu_conf.get("reporter", None))
         do_report = default_if_arg_none(do_report, kensu_conf.getboolean("do_report", True))
         report_to_file = default_if_arg_none(report_to_file, kensu_conf.getboolean("report_to_file", False))
         offline_file_name = default_if_arg_none(offline_file_name, kensu_conf.get("offline_file_name", None))
@@ -139,6 +158,15 @@ class Kensu(object):
 
         # add function to Kensu entities
         injection = Injection()
+
+        # reporter could be either an instance of Reporter already, or None, or a String (the class name of the reporter)
+        reporter_config = None
+
+        if isinstance(reporter, str) or config.has_section('kensu.reporter'):
+            reporter = Reporter.create(config['kensu.reporter'], reporter)
+        elif reporter is not None and hasattr(reporter, '__call__'):
+            reporter = GenericReporter(reporter)
+
         injection.set_reporter(reporter)
         injection.set_do_report(do_report, offline_file_name=offline_file_name, report_to_file=report_to_file)
         injection.set_kensu_api(self.kensu_api)
@@ -148,6 +176,7 @@ class Kensu(object):
         self.report_in_mem = report_in_mem
         self.compute_stats = compute_stats
         self.offline_file_name = offline_file_name
+        self.sql_util_url = sql_util_url
 
         self.set_default_physical_location(Kensu.UNKNOWN_PHYSICAL_LOCATION)
         # can be updated using set_default_physical_location
